==> vootoo-core-0.2.0-sources.jar: org/vootoo/search/WrappedNotCollectorFilterable.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.vootoo.search;

import java.io.IOException;
import java.util.Map;

import org.apache.lucene.index.AtomicReaderContext;

/**
 * wrapped <code>NOT</code> {@link CollectorFilterable}
 */
public class WrappedNotCollectorFilterable extends CollectorFilterable {

  private final CollectorFilterable collectorFilterable;

  public WrappedNotCollectorFilterable(CollectorFilterable collectorFilterable) {
    this.collectorFilterable = collectorFilterable;
  }

  @Override
  public boolean equals(Object o) {
    if (o instanceof WrappedNotCollectorFilterable) {
      this.collectorFilterable
          .equals(((WrappedNotCollectorFilterable) o).collectorFilterable);
    }
    return collectorFilterable.equals(o);
  }

  @Override
  public int hashCode() {
    return collectorFilterable.hashCode();
  }

  @Override
  public String description() {
    return "not." + collectorFilterable.description();
  }

  @Override
  public boolean matches(int doc) {
    return !collectorFilterable.matches(doc);
  }

  @SuppressWarnings("rawtypes")
  @Override
  public void setNextReader(Map context, AtomicReaderContext readerContext)
      throws IOException {
    collectorFilterable.setNextReader(context, readerContext);
  }

}

==> vootoo-core-0.5.1-sources.jar: org/vootoo/search/WrappedNotCollectorFilterable.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.vootoo.search;

import org.apache.lucene.index.LeafReaderContext;

import java.io.IOException;
import java.util.Map;

/**
 * wrapped <code>NOT</code> {@link CollectorFilterable}
 */
public class WrappedNotCollectorFilterable extends CollectorFilterable {

  private final CollectorFilterable collectorFilterable;

  public WrappedNotCollectorFilterable(CollectorFilterable collectorFilterable) {
    this.collectorFilterable = collectorFilterable;
  }

  @Override
  public boolean equals(Object o) {
    if (o instanceof WrappedNotCollectorFilterable) {
      this.collectorFilterable
          .equals(((WrappedNotCollectorFilterable) o).collectorFilterable);
    }
    return collectorFilterable.equals(o);
  }

  @Override
  public int hashCode() {
    return collectorFilterable.hashCode();
  }

  @Override
  public String description() {
    return "not." + collectorFilterable.description();
  }

  @Override
  public boolean matches(int doc) {
    return !collectorFilterable.matches(doc);
  }

  @SuppressWarnings("rawtypes")
  @Override
  public void doSetNextReader(Map context, LeafReaderContext readerContext)
      throws IOException {
    collectorFilterable.doSetNextReader(context, readerContext);
  }

}
